pub enum Authority {
Literal,
Generated,
EntropyChannel,
}Expand description
Who is the reconstruction authority for an output interval.
Variants
Literal
Bytes reproduced verbatim from a literal object or inline literal.
Generated
Bytes deterministically generated (currently only by REPEAT_LAST).
EntropyChannel
Bytes decoded from a typed entropy channel.