Module limits

Module limits 

Centralized resource bounds.

Every decode and encode path takes a Limits. Untrusted descriptors must be rejected before catastrophic work is performed, so all arithmetic on declared lengths and offsets is checked against these bounds and uses checked integer operations.

Structs

Limits
Hard upper bounds applied while parsing and materializing a descriptor.