pub fn decode_to_bytes_with<R: ObjectResolver>(
bytes: &[u8],
resolver: &R,
limits: Limits,
) -> Result<(Vec<u8>, ParsedDescriptor)>Expand description
Parse and materialize in one step, resolving external objects through
resolver.
pub fn decode_to_bytes_with<R: ObjectResolver>(
bytes: &[u8],
resolver: &R,
limits: Limits,
) -> Result<(Vec<u8>, ParsedDescriptor)>Parse and materialize in one step, resolving external objects through
resolver.